import { Injectable } from '@angular/core';
import { CanActivate, Router } from '@angular/router';
import { Observable } from 'rxjs';
import { map, take } from 'rxjs/operators';
import { AuthService } from '../../../shared/data-access/service/auth.service';

@Injectable({
  providedIn: 'root',
})
export class AdminGuard implements CanActivate {
  constructor(
    private authService: AuthService,
    private router: Router
  ) {}

  canActivate(): Observable<boolean> {
    return this.authService.authState$.pipe(
      take(1),
      map(authState => {
        // Check authentication first
        if (!authState.isAuthenticated) {
          this.router.navigate(['/login']);
          return false;
        }

        // Check admin role
        if (authState.user?.role !== 'admin') {
          this.router.navigate(['/']);
          return false;
        }

        return true;
      })
    );
  }
}
